%% parse_status
%   parse the result of running the pvs status script. look for a
%   list of theorems and associated status return that in parsed
%   list.
% inputs:
%   object:PVS_checker - PVS_checker object
%   string:string - string containing output of runnign pvs script
% outputs:
%   parsed:array - array containing each of the theorems of the pvs
%   file followed by its status so will look something like
%   ['TCC1' 'proved' 'TCC2' 'unfinished']... etc
% Author: Colin Eles elesc@mcmaster.ca
% Organization: McMaster Centre for Software Certification
function [parsed] = parse_status(object,string)
thrms_status = regexp(string,'\w+(?=[\.]{4,})|(?<=[\.]{4,})\w+','match');
parsed = thrms_status;

end